#!/bin/bash
#set -x

usage ()
{
  echo 'Usage : launcher.sh [ --os ] [ --pkg-info  <package> ] [ --pkg-upgrade <package> ] [ --tunnel USER@SERVER:PORT ] [ --get-instance ] [ --get-sn ] [ --get-sim-ccid ] [ --reset ]'
  exit
}
#################################################################
while [ "$1" != "" ]; do
case $1 in
        --os )        		OS=1
                       		;;
        --pkg-info )        	shift
                       		PKG_INF=$1
                       		;;
	--pkg-upgrade )		shift
				PKG=$1
				;;
	--tunnel )		shift
				TUNNEL=$1
				;;
	--get-instance )
				GET_INST=1
				;;
	--get-sn )		SN=1
				;;
	--get-sim-ccid )	SIM_CCID=1
				;;
        --reset )	        RESET=1
                                ;;
        * )
				usage
    esac
    shift
done

##################################################################
if [[ -f /proc/device-tree/compatible ]]; then
DT_COMPAT_LIST=`tr < /proc/device-tree/compatible  '\000' '\n'`

    for compat in $DT_COMPAT_LIST; do
        case "$compat" in
            "onion,omega2p" )
                INSPARK_HW_VERSION=SmartMetrix;
                break;
            ;;
            "mub" )
                INSPARK_HW_VERSION=milandr;
                break;
            ;;

	    "inspark,imx28-inspark55" | "contactless,imx28-wirenboard55" )
     		INSPARK_HW_VERSION=imx287;
                break;
            ;;

        esac
    done;
fi
###############################################################
PKG_MAN='apt-get'
TOPIC="/Controller/Out/Event"
###############################################################
function publish()
{
	DATE=`date "+%d.%m.%Y %H:%M:%S"`
	MSG="E;4007;"${DATE}";${1}=${2}"
	/usr/bin/mosquitto_pub -t ${TOPIC} -m "${MSG}"
}

function pkg_manager_check()
{
if [[ -f /bin/opkg ]]; then
	PKG_MAN='opkg'
	OS_VER=wrt
fi
}

function pkg_ver()
{
if [[ $OS_VER == 'wrt' ]]; then
	publish $PKG_INF `opkg status $PKG_INF | awk '/Version/{print $2}'`
else
	publish $PKG_INF `dpkg -l $PKG_INF | awk '/ii/{print $3}'`
fi
}

function install()
{
$PKG_MAN update && $PKG_MAN install $1 > /dev/null 2>&1
}

function tunnel()
{
	ssh -S /tmp/ssh_socket -O check placeholder 2>&- || 
	(
#		SSH_USER=`awk -F@ '{print $1}' <<< $TUNNEL`
		SSH_SERVER=`awk -F: '{print $1}' <<< $TUNNEL`
		SSH_PORT=`awk -F: '{print $2}' <<< $TUNNEL`
        	ssh -fNMS /tmp/ssh_socket \
			-o LogLevel=quiet \
			-o UserKnownHostsFile=/dev/null \
			-p ${SSH_PORT} ${SSH_SERVER} || exit 1
       		ssh -S /tmp/ssh_socket -O check placeholder 2>&-
		SSH_PORT=`ssh -S /tmp/ssh_socket -O forward -R 0:localhost:22 placeholder`
		publish tunnel ${SSH_PORT}
		(
			sleep 600
			ssh -S /tmp/ssh_socket -O exit -R 0:localhost:22 placeholder 2>&-
		)&
	)
}

function get_instance ()
{
	INSTANCE=`cat /etc/mosquitto/conf.d/bridge.conf | awk -F/ '/Measure/{print $5}'`
	[[ -z "$INSTANCE" ]] || publish instance ${INSTANCE}
}

function get_sn ()
{
        publish SerialNumber `cat /var/inspark/vsn`
}

function get_sim_ccid ()
{
	SIM_CCID=$(cat /var/log/at.log | awk 'NR==2{print $2}')
        if [[ -z "$SIM_CCID" ]]; then
                SIM_CCID=$(cat /var/log/at.log | awk 'NR==2')
        else
                SIM_CCID = $SIM_CCID
        fi
	publish CCID $SIM_CCID
}

function reset(){
rm -rf /var/inspark/*.*  /etc/vmon.json /etc/vplan.json
/etc/init.d/vmon restart
/etc/init.d/vplan restart
}

################################################################
pkg_manager_check
[[ -z "$PKG_INF" ]] || ( pkg_ver )
[[ -z "$OS" ]] || ( publish os `cat /etc/os-release | awk -F= '/VERSION=/{print $2}'` )
[[ -z "$PKG" ]] || ( install $PKG )
[[ -z "$TUNNEL" ]] || ( tunnel $SSH_PORT $SSH_SERVER ) || exit 1
[[ -z "$GET_INST" ]] || ( get_instance )
[[ -z "$SN" ]] || ( get_sn )
[[ -z "$SIM_CCID" ]] || ( get_sim_ccid )
[[ -z "$RESET" ]] || ( reset )

